@@ -41,6 +41,8 @@ namespace Stats {
 class QueryPrivate;
 
 /**
+ * @class KActivities::Stats::Query query.h <KActivities/Stats/Query>
+ *
  * The activities system tracks resources (documents, contacts, etc.)
  * that the user has used. It also allows linking resources to
  * specific activities (like bookmarks, favorites, etc.).
@@ -51,20 +53,20 @@ class QueryPrivate;
  *
  * It allows filtering the results depending on the resource type,
  * the agent (application that reported the usage event,
- * @see KActivities::ResourceInstance) and the activity the resource
+ * see KActivities::ResourceInstance) and the activity the resource
  * has been used in, or linked to. It also allows filtering
  * on the URL of the resource.
  *
  * While it can be explicitly instantiated, a preferred approach
  * is to use the pipe syntax like this:
  *
- * <code>
+ * @code
  * auto query = UsedResources
  *                 | RecentlyUsedFirst
  *                 | Agent::any()
  *                 | Type::any()
  *                 | Activity::current();
- * </code>
+ * @endcode
  */
 class KACTIVITIESSTATS_EXPORT Query {
 public:
@@ -89,6 +91,8 @@ public:
     Terms::Order ordering() const;
     int offset() const;
     int limit() const;
+    QDate dateStart() const;
+    QDate dateEnd() const;
 
     void setSelection(Terms::Select selection);
 
@@ -96,9 +100,31 @@ public:
     void addAgents(const QStringList &agents);
     void addActivities(const QStringList &activities);
     void addUrlFilters(const QStringList &urlFilters);
+    /**
+     * @since 5.62
+     */
+    void setTypes(const Terms::Type &types);
+    /**
+     * @since 5.62
+     */
+    void setAgents(const Terms::Agent &agents);
+    /**
+     * @since 5.62
+     */
+    void setActivities(const Terms::Activity &activities);
+    /**
+     * @since 5.62
+     */
+    void setUrlFilters(const Terms::Url &urlFilters);
     void setOrdering(Terms::Order ordering);
     void setOffset(int offset);
     void setLimit(int limit);
+    /**
+     * @since 5.62
+     */
+    void setDate(const Terms::Date &date);
+    void setDateStart(QDate date);
+    void setDateEnd(QDate date);
 
     void clearTypes();
     void clearAgents();
@@ -151,6 +177,12 @@ private:
         setOffset(offset.value);
     }
 
+    inline void addTerm(Terms::Date date)
+    {
+        setDateStart(date.start);
+        setDateEnd(date.end);
+    }
+
 public:
 
     template <typename Term>
@@ -167,7 +199,7 @@ public:
     inline Query operator| (Query &&query, Term &&term)
     {
         query.addTerm(term);
-        return query;
+        return std::move(query);
     }
 
 private:
