@@ -46,13 +46,14 @@
 #include "resultwatcher.h"
 #include "cleaning.h"
 #include "kactivities/consumer.h"
+#include "kactivities-stats-logsettings.h"
 
 #include <common/specialvalues.h>
 
 #define MAX_CHUNK_LOAD_SIZE 50
 #define MAX_RELOAD_CACHE_SIZE 50
 
-#define QDBG qDebug() << "KActivitiesStats(" << (void*)this << ")"
+#define QDBG qCDebug(KACTIVITIES_STATS_LOG) << "KActivitiesStats(" << (void*)this << ")"
 
 namespace KActivities {
 namespace Stats {
@@ -109,7 +110,7 @@ public:
                                             int position)
         {
             if (!m_orderingConfig.isValid()) {
-                qWarning() << "We can not reorder the results, no clientId was specified";
+                qCWarning(KACTIVITIES_STATS_LOG) << "We can not reorder the results, no clientId was specified";
                 return;
             }
 
@@ -137,7 +138,7 @@ public:
             // not others
             QStringList linkedItems;
 
-            foreach (const ResultSet::Result &item, m_items) {
+            for (const ResultSet::Result &item : qAsConst(m_items)) {
                 if (item.linkStatus() == ResultSet::Result::NotLinked) break;
                 linkedItems << item.resource();
             }
@@ -192,14 +193,14 @@ public:
         inline void debug() const
         {
             for (const auto& item: m_items) {
-                qDebug() << "Item: " << item;
+                qCDebug(KACTIVITIES_STATS_LOG) << "Item: " << item;
             }
         }
 
         void loadOrderingConfig(const QString &activityTag)
         {
             if (!m_configFile) {
-                qDebug() << "Nothing to load - the client id is empty";
+                qCDebug(KACTIVITIES_STATS_LOG) << "Nothing to load - the client id is empty";
                 return;
             }
 
@@ -1041,8 +1042,10 @@ bool ResultModel::canFetchMore(const QModelIndex &parent) const
 
 void ResultModel::forgetResource(const QString &resource)
 {
-    foreach (const QString &activity, d->query.activities()) {
-        foreach (const QString &agent, d->query.agents()) {
+    const auto lstActivities = d->query.activities();
+    for (const QString &activity : lstActivities) {
+        const auto lstAgents = d->query.agents();
+        for (const QString &agent : lstAgents) {
             Stats::forgetResource(
                     activity,
                     agent == CURRENT_AGENT_TAG ?
@@ -1055,9 +1058,10 @@ void ResultModel::forgetResource(const QString &resource)
 void ResultModel::forgetResource(int row)
 {
     if (row >= d->cache.size()) return;
-
-    foreach (const QString &activity, d->query.activities()) {
-        foreach (const QString &agent, d->query.agents()) {
+    const auto lstActivities = d->query.activities();
+    for (const QString &activity : lstActivities) {
+        const auto lstAgents = d->query.agents();
+        for (const QString &agent : lstAgents) {
             Stats::forgetResource(
                     activity,
                     agent == CURRENT_AGENT_TAG ?
